#ifndef Rcpp_proxy_proxy_h
#define Rcpp_proxy_proxy_h

#include <Rcpp/proxy/TagProxy.h>
#include <Rcpp/proxy/ProtectedProxy.h>
#include <Rcpp/proxy/NameProxy.h>
#include <Rcpp/proxy/NamesProxy.h>
#include <Rcpp/proxy/Binding.h>
#include <Rcpp/proxy/SlotProxy.h>
#include <Rcpp/proxy/AttributeProxy.h>
#include <Rcpp/proxy/FieldProxy.h>
#include <Rcpp/proxy/DottedPairProxy.h>
#include <Rcpp/proxy/DottedPairMultipleNamedProxyPolicy.h>
#include <Rcpp/proxy/AttributesProxy.h>

#endif
